@@ -3,7 +3,7 @@ package SQL::Composer;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 require Carp;
 use SQL::Composer::Select;
@@ -84,10 +84,9 @@ SQL::Composer - sql builder
 
 =head1 DESCRIPTION
 
-L<SQL::Composer> is a SQL builder and rows parser in one module. It behaves very
-close to L<SQL::Abstract> or similar modules but allows deep joins and automatic
-convertion from arrayref to a hashref, keeping the nested join structure if
-needed.
+L<SQL::Composer> is a SQL builder and rows parser in one module. It allows deep
+joins and automatic convertion from arrayref to a hashref, keeping the nested
+join structure if needed.
 
 This module itself is just a factory for the common SQL statements: C<SELECT>,
 C<DELETE>, C<INSERT> and C<UPDATE>.
@@ -163,6 +162,10 @@ For more details see L<SQL::Composer::Select>.
 
     my $objects = $expr->from_rows([['c', 'd']]); # [{a => 'c', b => 'd'}];
 
+=head1 SEE ALSO
+
+L<SQL::Abstract>
+
 =head1 AUTHOR
 
 Viacheslav Tykhanovskyi
